@@ -24,8 +24,8 @@ THUMBNAIL_QUALITY = 30
 IMTYPE_DEFAULT = cv2.IMREAD_ANYCOLOR
 INTER_DEFAULT = cv2.INTER_LINEAR
 
-ENCODE_JPEG = ".jpg"
-ENCODE_PNG = ".png"
+ENCODE_JPEG = 0
+ENCODE_PNG = 1
 
 FLIP_VERTICAL = 0
 FLIP_HORIZONTAL = 1
